@@ -3,6 +3,7 @@ from . import std_types
 
 default = TypeSet()
 default.register(std_types.StdVector)
+default.register(std_types.StdVectorBool)
 default.register(std_types.StdArray)
 default.register(std_types.Pointer)
 default.register(std_types.Array)
@@ -10,4 +11,5 @@ default.register(std_types.Double)
 default.register(std_types.Float)
 default.register(std_types.StdComplexDouble)
 default.register(std_types.StdComplexFloat)
-default.register(std_types.Integral)
\ No newline at end of file
+default.register(std_types.Integral)
+default.register(std_types.Bool)
\ No newline at end of file
